@@ -37,6 +37,8 @@ import threading
 from functools import partial
 from multiprocessing import Pool
 from enum import IntEnum
+from typing import Tuple
+from numbers import Number
 
 import h5py
 import numpy
@@ -546,13 +548,18 @@ class Dataset:
                 values += [data.get_value(kind=kind, name=key)[0]]
             except KeyError:
                 missing_value = True
-                values += ["0"]
+                if len(values):
+                    values += [values[-1]]
+                else:
+                    values = ["0"]
 
         if missing_value:
             import warnings
 
             warnings.warn(
-                "Missing value(s) filled to 0 for kind {} and key {}".format(key, kind)
+                "Missing value(s) filled to previous value for kind {} and key {}".format(
+                    key, kind
+                )
             )
 
         return values
@@ -1088,18 +1095,15 @@ class Dataset:
                 return
             new_data = Data(urls, self.running_data.metadata, self._in_memory)
 
-        transformation = (
-            Transformation(
-                self.transformation.kind,
-                [
-                    apply_2D_ROI(axis, origin, size, center)
-                    for axis in self.transformation.transformation
-                ],
-                self.transformation.rotate,
+        transformation = self.transformation
+        if transformation is not None:
+            transformation = Transformation(
+                transformation.kind,
+                apply_2D_ROI(transformation.x, origin, size, center),
+                apply_2D_ROI(transformation.y, origin, size, center),
+                transformation.rotate,
             )
-            if self.transformation
-            else None
-        )
+
         if indices is None:
             shape = list(self.data.shape)[:-2]
             shape.append(new_data.shape[-2])
@@ -1375,7 +1379,7 @@ class Dataset:
         W = None
         H = None
         shape = numpy.asarray(self.get_data(0).shape)
-        first_size = (shape / (len(iterations) + 1)).astype(numpy.int)
+        first_size = (shape / (len(iterations) + 1)).astype(int)
         size = first_size
 
         if not os.path.isdir(os.path.join(self.dir, "waterfall")):
@@ -1909,8 +1913,7 @@ class Dataset:
         if self.dims.ndim == 1 and kind == "rsm":
             ffz = self.get_metadata_values(POSITIONER_METADATA, "ffz")[0]
             mainx = -self.get_metadata_values(POSITIONER_METADATA, "mainx")[0]
-            transformation = compute_rsm(H, W, d, ffz, mainx, rotate)
-            self.transformation = Transformation(kind, transformation, rotate)
+            x, y = compute_rsm(H, W, d, ffz, mainx, rotate)
         else:
             obx = self.get_metadata_values(POSITIONER_METADATA, "obx")[0]
             obpitch = numpy.unique(
@@ -1918,11 +1921,10 @@ class Dataset:
             )
             obpitch = obpitch[len(obpitch) // 2]
             mainx = -self.get_metadata_values(POSITIONER_METADATA, "mainx")[0]
-            self.transformation = Transformation(
-                kind,
-                compute_magnification(H, W, d, obx, obpitch, mainx, topography, center),
-                rotate,
+            x, y = compute_magnification(
+                H, W, d, obx, obpitch, mainx, topography, center
             )
+        self.transformation = Transformation(kind, x, y, rotate)
 
     def project_data(self, dimension, indices=None, _dir=None):
 
@@ -2013,8 +2015,8 @@ class Dataset:
         return calculate_RSM_histogram(
             data=self.get_data(),
             diffry_values=diffry,
-            twotheta=transformation.transformation[1],
-            eta=transformation.transformation[0],
+            twotheta=transformation.y,
+            eta=transformation.x,
             Q=Q,
             a=a,
             map_range=map_range,
@@ -2498,11 +2500,58 @@ class Data(numpy.ndarray):
 
 
 class Transformation:
-    def __init__(self, kind, transformation, rotate):
-        self.transformation = transformation
+    def __init__(self, kind: str, x: numpy.ndarray, y: numpy.ndarray, rotate: bool):
+        self.x = x  # shape (sy, sx)
+        self.y = y  # shape (sy, sx)
         self.rotate = rotate
         self.kind = kind
 
     @property
-    def label(self):
+    def shape(self) -> Tuple[int, int]:
+        return self.x.shape
+
+    @property
+    def sx(self) -> int:
+        return self.shape[1]
+
+    @property
+    def sy(self) -> int:
+        return self.shape[0]
+
+    @property
+    def label(self) -> str:
         return "degrees" if self.kind == "rsm" else "µm"
+
+    @property
+    def xregular(self) -> numpy.ndarray:
+        return self.xscale * numpy.arange(self.sx) + self.xorigin
+
+    @property
+    def yregular(self) -> numpy.ndarray:
+        return self.yscale * numpy.arange(self.sy) + self.yorigin
+
+    @property
+    def xorigin(self) -> Number:
+        return self.x[0][0]
+
+    @property
+    def yorigin(self) -> Number:
+        return self.y[0][0]
+
+    @property
+    def origin(self) -> Tuple[Number, Number]:
+        return self.xorigin, self.yorigin
+
+    @property
+    def xscale(self) -> Number:
+        x = self.x
+        return (x[-1][-1] - x[0][0]) / self.sx
+
+    @property
+    def yscale(self) -> Number:
+        y = self.y
+        return (y[-1][-1] - y[0][0]) / self.sy
+
+    @property
+    def scale(self) -> Tuple[Number, Number]:
+        return self.xscale, self.yscale
