@@ -397,7 +397,7 @@ def compute_rsm(H, W, d, ffz, mainx, rotate=False):
         z, y = numpy.meshgrid(z, y, indexing="ij")
     eta = numpy.arctan2(y, z)
     twotheta = numpy.arctan2(numpy.sqrt(y * y + z * z), mainx)
-    return eta, twotheta
+    return numpy.degrees(eta), numpy.degrees(twotheta)
 
 
 def compute_magnification(
