@@ -664,9 +664,7 @@ class TestDataset(unittest.TestCase):
         )
         dataset.compute_transformation(d=0.1, kind="rsm")
 
-        self.assertEqual(
-            dataset.transformation.transformation[0].shape, dataset.get_data(0).shape
-        )
+        self.assertEqual(dataset.transformation.shape, dataset.get_data(0).shape)
 
     def test_apply_rsm_in_disk(self):
         """Tests fitting data in disk"""
@@ -676,9 +674,7 @@ class TestDataset(unittest.TestCase):
         )
         dataset.compute_transformation(d=0.1, kind="rsm")
 
-        self.assertEqual(
-            dataset.transformation.transformation[1].shape, dataset.get_data(0).shape
-        )
+        self.assertEqual(dataset.transformation.shape, dataset.get_data(0).shape)
 
 
 class TestData(unittest.TestCase):
