@@ -331,10 +331,21 @@ class DimensionWidget(DimensionMapping):
                                 metadata = metadata[0]
                         else:
                             metadata = self._update_dataset.data.metadata
-                        values = [
-                            data.get_value(kind=dimension.kind, name=dimension.name)[0]
-                            for data in metadata
-                        ]
+                        # missing_value = False
+                        for data in metadata:
+                            try:
+                                values += [
+                                    data.get_value(
+                                        kind=dimension.kind, name=dimension.name
+                                    )[0]
+                                ]
+                            except KeyError:
+                                # missing_value = True
+                                if len(values):
+                                    values += [values[-1]]
+                                else:
+                                    values = ["0"]
+
                         dimension.set_unique_values(values)
                 except ValueError:
                     for axis, dimension in self.dataset.dims:
