@@ -136,7 +136,7 @@ class GrainPlotWidget(qt.QMainWindow):
         :param Dataset dataset: dataset
         """
         self._parent = parent
-        self._dataset = dataset
+        self.dataset = dataset
         self.indices = indices
         self.bg_indices = bg_indices
         self.bg_dataset = bg_dataset
@@ -147,26 +147,16 @@ class GrainPlotWidget(qt.QMainWindow):
         for i in range(len(Method)):
             self._methodCB.model().item(i).setEnabled(False)
         self._methodCB.blockSignals(state)
-        if self._dataset.transformation:
-            transformation = self._dataset.transformation.transformation
-            eta = numpy.degrees(transformation[0])
-            twotheta = numpy.degrees(transformation[1])
-            px = eta[0][0]
-            py = twotheta[0][0]
-            xscale = (eta[-1][-1] - px) / eta.shape[1]
-            yscale = (twotheta[-1][-1] - py) / twotheta.shape[0]
-            self.origin = (px, py)
-            self.scale = (xscale, yscale)
-        if self._dataset.dims.ndim > 1 and self._dataset.dims.ndim < 4:
+        if self.dataset.dims.ndim > 1 and self.dataset.dims.ndim < 4:
             self._curves = {}
-            if self._dataset.dims.ndim == 3:
+            if self.dataset.dims.ndim == 3:
                 # Update chooseDimensionWidget and thirdMotorCB
                 state = self._chooseDimensionWidget.blockSignals(True)
-                self._chooseDimensionWidget.setDimensions(self._dataset.dims)
+                self._chooseDimensionWidget.setDimensions(self.dataset.dims)
                 self._chooseDimensionWidget._updateState(True)
                 self._chooseDimensionWidget.blockSignals(state)
                 self._thirdMotorCB.clear()
-                third_motor = self._dataset.dims.get(
+                third_motor = self.dataset.dims.get(
                     int(
                         numpy.setdiff1d(
                             range(3), self._chooseDimensionWidget.dimension
@@ -178,7 +168,7 @@ class GrainPlotWidget(qt.QMainWindow):
                     numpy.array(third_motor.unique_values, dtype=str)
                 )
                 self._thirdMotorCB.blockSignals(state)
-            self.ori_dist, self.hsv_key = self._dataset.compute_mosaicity_colorkey(
+            self.ori_dist, self.hsv_key = self.dataset.compute_mosaicity_colorkey(
                 third_motor=0
             )
             self._checkboxStateChanged()
@@ -191,7 +181,7 @@ class GrainPlotWidget(qt.QMainWindow):
             self._computeContoursB.clicked.connect(self._computeContours)
             self._methodCB.model().item(4).setEnabled(True)
             self._methodCB.setCurrentIndex(4)
-        self._thread = OperationThread(self, self._dataset.apply_moments)
+        self._thread = OperationThread(self, self.dataset.apply_moments)
         self._thread.setArgs(self.indices)
         self._thread.finished.connect(self._updateData)
         self._thread.start()
@@ -199,15 +189,15 @@ class GrainPlotWidget(qt.QMainWindow):
             self._plotWidget.layout().itemAt(i).widget().setParent(None)
 
         self._contoursPlot.setGraphTitle(
-            self._dataset.title + "\n" + Method.ORI_DIST.value
+            self.dataset.title + "\n" + Method.ORI_DIST.value
         )
         self._mosaicityPlot.setGraphTitle(
-            self._dataset.title + "\n" + Method.MOSAICITY.value
+            self.dataset.title + "\n" + Method.MOSAICITY.value
         )
         self._plots = []
-        for axis, dim in self._dataset.dims:
+        for axis, dim in self.dataset.dims:
             self._plots += [Plot2D(parent=self)]
-            self._plots[-1].setGraphTitle(self._dataset.title + "\n" + dim.name)
+            self._plots[-1].setGraphTitle(self.dataset.title + "\n" + dim.name)
             self._plots[-1].setDefaultColormap(Colormap(name="viridis"))
             self._plotWidget.layout().addWidget(self._plots[-1])
 
@@ -218,13 +208,8 @@ class GrainPlotWidget(qt.QMainWindow):
         self._thread.finished.disconnect(self._updateData)
         if self._thread.data is not None:
             self._moments = self._thread.data
-            if self._dataset.transformation and self._dataset.transformation.rotate:
-                for axis in self._moments:
-                    self._moments[axis] = [
-                        numpy.rot90(moment, 3) for moment in self._moments[axis]
-                    ]
             self._updatePlot(self._methodCB.currentText())
-            rg = len(Method) if self._dataset.dims.ndim > 1 else 4
+            rg = len(Method) if self.dataset.dims.ndim > 1 else 4
             for i in range(rg):
                 self._methodCB.model().item(i).setEnabled(True)
             self.mosaicity = self.compute_mosaicity()
@@ -241,7 +226,7 @@ class GrainPlotWidget(qt.QMainWindow):
 
     def _updateDataset(self, widget, dataset):
         self._parent._updateDataset(widget, dataset)
-        self._dataset = dataset
+        self.dataset = dataset
 
     def _checkboxStateChanged(self, state=None):
         """
@@ -251,8 +236,8 @@ class GrainPlotWidget(qt.QMainWindow):
         self._contoursPlot.remove(kind="curve")
         self._contoursPlot.resetZoom()
         scale = 100
-        xdim = self._dataset.dims.get(self.dimensions[1])
-        ydim = self._dataset.dims.get(self.dimensions[0])
+        xdim = self.dataset.dims.get(self.dimensions[1])
+        ydim = self.dataset.dims.get(self.dimensions[0])
         xscale = xdim.range[2]
         yscale = ydim.range[2]
         if self._motorValuesCheckbox.isChecked():
@@ -290,8 +275,8 @@ class GrainPlotWidget(qt.QMainWindow):
                 levels.append(i)
 
             colors = self._curvesColormap.applyToData(levels)
-            xdim = self._dataset.dims.get(self.dimensions[1])
-            ydim = self._dataset.dims.get(self.dimensions[0])
+            xdim = self.dataset.dims.get(self.dimensions[1])
+            ydim = self.dataset.dims.get(self.dimensions[0])
             self._curves = {}
             for ipolygon, polygon in enumerate(polygons):
                 # iso contours
@@ -324,7 +309,7 @@ class GrainPlotWidget(qt.QMainWindow):
         """
         Compute mosaicity map depending on the selected dimensions, if any.
         """
-        if self._moments is not None and self._dataset.dims.ndim > 1:
+        if self._moments is not None and self.dataset.dims.ndim > 1:
             com0 = self._moments[self.dimensions[0]][0]
             no_nans_indices = ~numpy.isnan(com0)
             min_com0 = numpy.min(
@@ -345,8 +330,6 @@ class GrainPlotWidget(qt.QMainWindow):
                     (norms0, norms1, numpy.ones(self._moments[0].shape[1:])), axis=2
                 )
             )
-            if self._dataset.transformation and self._dataset.transformation.rotate:
-                mosaicity = numpy.rot90(mosaicity, 3)
             return mosaicity
 
     def _updatePlot(self, method):
@@ -361,86 +344,31 @@ class GrainPlotWidget(qt.QMainWindow):
         if method == Method.ORI_DIST:
             self._levelsWidget.show()
             self._plotWidget.hide()
-            if self._dataset.dims.ndim == 3:
+            if self.dataset.dims.ndim == 3:
                 self._chooseDimensionWidget.show()
                 self._thirdMotorCB.show()
         elif method == Method.FWHM:
             self._plotWidget.show()
-            if self._dataset.transformation is not None:
-                label = self._dataset.transformation.label
-                for i, plot in enumerate(self._plots):
-                    plot.addImage(
-                        self._moments[i][1],
-                        origin=self.origin,
-                        scale=self.scale,
-                        xlabel=label,
-                        ylabel=label,
-                    )
-            else:
-                for i, plot in enumerate(self._plots):
-                    plot.addImage(self._moments[i][1])
+            for i, plot in enumerate(self._plots):
+                self._addImage(plot, self._moments[i][1])
         elif method == Method.COM:
             self._plotWidget.show()
-            if self._dataset.transformation is not None:
-                label = self._dataset.transformation.label
-                for i, plot in enumerate(self._plots):
-                    plot.addImage(
-                        self._moments[i][0],
-                        origin=self.origin,
-                        scale=self.scale,
-                        xlabel=label,
-                        ylabel=label,
-                    )
-            else:
-                for i, plot in enumerate(self._plots):
-                    plot.addImage(self._moments[i][0], xlabel="pixels", ylabel="pixels")
+            for i, plot in enumerate(self._plots):
+                self._addImage(plot, self._moments[i][0])
         elif method == Method.SKEWNESS:
             self._plotWidget.show()
-            if self._dataset.transformation is not None:
-                label = self._dataset.transformation.label
-                for i, plot in enumerate(self._plots):
-                    plot.addImage(
-                        self._moments[i][2],
-                        origin=self.origin,
-                        scale=self.scale,
-                        xlabel=label,
-                        ylabel=label,
-                    )
-            else:
-                for i, plot in enumerate(self._plots):
-                    plot.addImage(self._moments[i][2], xlabel="pixels", ylabel="pixels")
+            for i, plot in enumerate(self._plots):
+                self._addImage(plot, self._moments[i][2])
         elif method == Method.KURTOSIS:
             self._plotWidget.show()
-            if self._dataset.transformation is not None:
-                label = self._dataset.transformation.label
-                for i, plot in enumerate(self._plots):
-                    plot.addImage(
-                        self._moments[i][3],
-                        origin=self.origin,
-                        scale=self.scale,
-                        xlabel=label,
-                        ylabel=label,
-                    )
-            else:
-                for i, plot in enumerate(self._plots):
-                    plot.addImage(self._moments[i][3], xlabel="pixels", ylabel="pixels")
+            for i, plot in enumerate(self._plots):
+                self._addImage(plot, self._moments[i][3])
         elif method == Method.MOSAICITY:
             try:
                 self._plotWidget.hide()
-                if self._dataset.transformation:
-                    label = self._dataset.transformation.label
-                    self._mosaicityPlot.addImage(
-                        self.mosaicity,
-                        origin=self.origin,
-                        scale=self.scale,
-                        xlabel=label,
-                        ylabel=label,
-                    )
-                else:
-                    self._mosaicityPlot.addImage(self.mosaicity)
-
+                self._addImage(self._mosaicityPlot, self.mosaicity)
                 self._mosaicityPlot.show()
-                if self._dataset.dims.ndim == 3:
+                if self.dataset.dims.ndim == 3:
                     self._chooseDimensionWidget.show()
             except Exception as e:
                 _logger.error("Couldn't compute mosaicity: ", e)
@@ -454,13 +382,13 @@ class GrainPlotWidget(qt.QMainWindow):
         """
 
         self.dimensions = self._chooseDimensionWidget.dimension
-        self.ori_dist, self.hsv_key = self._dataset.compute_mosaicity_colorkey(
+        self.ori_dist, self.hsv_key = self.dataset.compute_mosaicity_colorkey(
             dimensions=self.dimensions, third_motor=0
         )
         self.mosaicity = self.compute_mosaicity()
 
         self._thirdMotorCB.clear()
-        third_motor = self._dataset.dims.get(
+        third_motor = self.dataset.dims.get(
             int(numpy.setdiff1d(range(3), self.dimensions)[0])
         )
 
@@ -480,7 +408,7 @@ class GrainPlotWidget(qt.QMainWindow):
         Update orientation distribution according to the third motor chosen
         """
         if index > -1:
-            self.ori_dist, self.hsv_key = self._dataset.compute_mosaicity_colorkey(
+            self.ori_dist, self.hsv_key = self.dataset.compute_mosaicity_colorkey(
                 dimensions=self._chooseDimensionWidget.dimension, third_motor=index
             )
 
@@ -506,23 +434,22 @@ class GrainPlotWidget(qt.QMainWindow):
         """
         Creates dictionay with maps information and exports it to a nexus file
         """
-        if self._dataset.transformation:
-            shape = self._dataset.get_data(0).shape
+        if self.dataset.transformation:
             axes = [
-                [self.origin[1] + i * self.scale[1] for i in range(shape[0])],
-                [self.origin[0] + i * self.scale[0] for i in range(shape[1])],
+                self.dataset.transformation.yregular,
+                self.dataset.transformation.xregular,
             ]
             axes_names = ["y", "x"]
             axes_long_names = [
-                self._dataset.transformation.label,
-                self._dataset.transformation.label,
+                self.dataset.transformation.label,
+                self.dataset.transformation.label,
             ]
         else:
             axes = None
             axes_names = None
             axes_long_names = None
 
-        if self._dataset and self._dataset.dims.ndim > 1:
+        if self.dataset and self.dataset.dims.ndim > 1:
             nx = {
                 "entry": {
                     Method.MOSAICITY.value: create_nxdata_dict(
@@ -551,7 +478,7 @@ class GrainPlotWidget(qt.QMainWindow):
                 "@default": "entry",
             }
 
-            for axis, dim in self._dataset.dims:
+            for axis, dim in self.dataset.dims:
                 nx["entry"][dim.name] = {"@NX_class": "NXcollection"}
                 for i in range(4):
                     nx["entry"][dim.name][Method.values()[i]] = create_nxdata_dict(
@@ -586,3 +513,17 @@ class GrainPlotWidget(qt.QMainWindow):
         fileDialog.setDefaultSuffix(".h5")
         if fileDialog.exec_():
             dicttonx(nx, fileDialog.selectedFiles()[0])
+
+    def _addImage(self, plot, image):
+        if self.dataset.transformation is None:
+            plot.addImage(image, xlabel="pixels", ylabel="pixels")
+            return
+        if self.dataset.transformation.rotate:
+            image = numpy.rot90(image, 3)
+        plot.addImage(
+            image,
+            origin=self.dataset.transformation.origin,
+            scale=self.dataset.transformation.scale,
+            xlabel=self.dataset.transformation.label,
+            ylabel=self.dataset.transformation.label,
+        )
