@@ -155,16 +155,6 @@ class RockingCurvesWidget(qt.QMainWindow):
         self.setStack()
         self._methodCB.clear()
         oldState = self._methodCB.blockSignals(True)
-        if self.dataset.transformation:
-            transformation = self.dataset.transformation.transformation
-            px = transformation[0][0][0]
-            py = transformation[1][0][0]
-            xscale = (transformation[0][-1][-1] - px) / transformation[0].shape[1]
-            yscale = (transformation[1][-1][-1] - py) / transformation[1].shape[0]
-            self.origin = (px, py)
-            self.scale = (xscale, yscale)
-        else:
-            self.origin, self.scale = None, None
         if self.dataset.dims.ndim == 2:
             self._methodCB.addItems(Maps_2D.values())
             self._methodCB.currentTextChanged.connect(self._update2DPlot)
@@ -430,61 +420,26 @@ class RockingCurvesWidget(qt.QMainWindow):
         """
         try:
             method = Maps(method)
-            label = (
-                self.dataset.transformation.label
-                if self.dataset.transformation is not None
-                else "pixels"
-            )
             title = self.dataset.title
             if title != "":
                 title += " - "
             if method == Maps.AMPLITUDE:
                 self._plotMaps.setGraphTitle(title + Maps.AMPLITUDE.value)
-                self._plotMaps.addImage(
-                    self.maps[0],
-                    origin=self.origin,
-                    scale=self.scale,
-                    xlabel=label,
-                    ylabel=label,
-                )
+                self._addImage(self.maps[0])
             elif method == Maps.FWHM:
                 self._plotMaps.setGraphTitle(title + Maps.FWHM.value)
-                self._plotMaps.addImage(
-                    self.maps[2],
-                    origin=self.origin,
-                    scale=self.scale,
-                    xlabel=label,
-                    ylabel=label,
-                )
+                self._addImage(self.maps[2])
             elif method == Maps.PEAK:
                 com = self.maps[1]
                 com[numpy.isnan(com)] = min(com[~numpy.isnan(com)])
                 self._plotMaps.setGraphTitle(title + Maps.PEAK.value)
-                self._plotMaps.addImage(
-                    com,
-                    origin=self.origin,
-                    scale=self.scale,
-                    xlabel=label,
-                    ylabel=label,
-                )
+                self._addImage(com)
             elif method == Maps.BACKGROUND:
                 self._plotMaps.setGraphTitle(title + Maps.BACKGROUND.value)
-                self._plotMaps.addImage(
-                    self.maps[3],
-                    origin=self.origin,
-                    scale=self.scale,
-                    xlabel=label,
-                    ylabel=label,
-                )
+                self._addImage(self.maps[3])
             elif method == Maps.RESIDUALS:
                 self._plotMaps.setGraphTitle(title + Maps.RESIDUALS.value)
-                self._plotMaps.addImage(
-                    self.residuals,
-                    origin=self.origin,
-                    scale=self.scale,
-                    xlabel=label,
-                    ylabel=label,
-                )
+                self._addImage(self.residuals)
         except ValueError:
             _logger.warning("Unexisting map method")
 
@@ -494,11 +449,6 @@ class RockingCurvesWidget(qt.QMainWindow):
         """
         try:
             method = Maps_2D(method)
-            label = (
-                self.dataset.transformation.label
-                if self.dataset.transformation is not None
-                else "pixels"
-            )
             title = self.dataset.title
             if title != "":
                 title += " - "
@@ -506,78 +456,30 @@ class RockingCurvesWidget(qt.QMainWindow):
                 com = self.maps[0]
                 com[numpy.isnan(com)] = min(com[~numpy.isnan(com)])
                 self._plotMaps.setGraphTitle(title + Maps_2D.PEAK_X.value)
-                self._plotMaps.addImage(
-                    com,
-                    origin=self.origin,
-                    scale=self.scale,
-                    xlabel=label,
-                    ylabel=label,
-                )
+                self._addImage(com)
             elif method == Maps_2D.PEAK_Y:
                 com = self.maps[1]
                 com[numpy.isnan(com)] = min(com[~numpy.isnan(com)])
                 self._plotMaps.setGraphTitle(title + Maps_2D.PEAK_Y.value)
-                self._plotMaps.addImage(
-                    com,
-                    origin=self.origin,
-                    scale=self.scale,
-                    xlabel=label,
-                    ylabel=label,
-                )
+                self._addImage(com)
             elif method == Maps_2D.FWHM_X:
                 self._plotMaps.setGraphTitle(title + Maps_2D.FWHM_X.value)
-                self._plotMaps.addImage(
-                    self.maps[2],
-                    origin=self.origin,
-                    scale=self.scale,
-                    xlabel=label,
-                    ylabel=label,
-                )
+                self._addImage(self.maps[2])
             elif method == Maps_2D.FWHM_Y:
                 self._plotMaps.setGraphTitle(title + Maps_2D.FWHM_Y.value)
-                self._plotMaps.addImage(
-                    self.maps[3],
-                    origin=self.origin,
-                    scale=self.scale,
-                    xlabel=label,
-                    ylabel=label,
-                )
+                self._addImage(self.maps[3])
             elif method == Maps_2D.AMPLITUDE:
                 self._plotMaps.setGraphTitle(title + Maps_2D.AMPLITUDE.value)
-                self._plotMaps.addImage(
-                    self.maps[4],
-                    origin=self.origin,
-                    scale=self.scale,
-                    xlabel=label,
-                    ylabel=label,
-                )
+                self._addImage(self.maps[4])
             elif method == Maps_2D.CORRELATION:
                 self._plotMaps.setGraphTitle(title + Maps_2D.CORRELATION.value)
-                self._plotMaps.addImage(
-                    self.maps[5],
-                    origin=self.origin,
-                    scale=self.scale,
-                    xlabel=label,
-                    ylabel=label,
-                )
+                self._addImage(self.maps[5])
             elif method == Maps_2D.BACKGROUND:
                 self._plotMaps.setGraphTitle(title + Maps_2D.BACKGROUND.value)
-                self._plotMaps.addImage(
-                    self.maps[6],
-                    origin=self.origin,
-                    scale=self.scale,
-                    xlabel=label,
-                    ylabel=label,
-                )
+                self._addImage(self.maps[6])
             elif method == Maps_2D.RESIDUALS:
                 self._plotMaps.setGraphTitle(title + Maps_2D.RESIDUALS.value)
-                self._plotMaps.addImage(
-                    self.residuals,
-                    origin=self.origin,
-                    scale=self.scale,
-                    xlabel=label,
-                    ylabel=label,
-                )
+                self._addImage(self.residuals)
         except ValueError:
             _logger.warning("Unexisting map method")
 
@@ -644,10 +546,9 @@ class RockingCurvesWidget(qt.QMainWindow):
         }
 
         if self.dataset.transformation:
-            shape = self.dataset.get_data(0).shape
             axes = [
-                [self.origin[1] + i * self.scale[1] for i in range(shape[0])],
-                [self.origin[0] + i * self.scale[0] for i in range(shape[1])],
+                self.dataset.transformation.yregular,
+                self.dataset.transformation.xregular,
             ]
             axes_names = ["y", "x"]
             axes_long_names = [
@@ -690,3 +591,17 @@ class RockingCurvesWidget(qt.QMainWindow):
         fileDialog.setDefaultSuffix(".h5")
         if fileDialog.exec_():
             dicttonx(nx, fileDialog.selectedFiles()[0])
+
+    def _addImage(self, image):
+        if self.dataset.transformation is None:
+            self._plotMaps.addImage(image, xlabel="pixels", ylabel="pixels")
+            return
+        if self.dataset.transformation.rotate:
+            image = numpy.rot90(image, 3)
+        self._plotMaps.addImage(
+            image,
+            origin=self.dataset.transformation.origin,
+            scale=self.dataset.transformation.scale,
+            xlabel=self.dataset.transformation.label,
+            ylabel=self.dataset.transformation.label,
+        )
